Adding customization plugins
============================

Limited support is offered for customizing the behavior of nbgrader through
using predefined plugin methods or by added your own custom plugin. See the
example usage below for the supported plugins and their API.

If you need further customized behavior please `open an issue
<https://github.com/jupyter/nbgrader/issues/new>`_.

:ref:`PRs are also welcome! <pull-request>`


Example usage
-------------

.. toctree::
    :maxdepth: 1

    late-plugin
    export-plugin
